from .assets import get_assets_by_layout_id
from .companies import get_companies_all
from .magicdash import create_magic_dash
from .users import get_users

__all__ = ["get_assets_by_layout_id", "get_companies_all", "create_magic_dash", get_users]


import requests
import logging

# create logger
logger = logging.getLogger(__name__)
logger.setLevel(logging.INFO)

def create_magic_dash(api_baseurl, api_key, dash_name, dash_message, dash_shade, dash_content, company_name):
    try:
        url = f"{api_baseurl}/magic_dash"
        payload = {
            "title": f"{dash_name}",
            "message": f"{dash_message}",
            "shade": f"{dash_shade}",
            "content": f"{dash_content}",
            "content_link": "",
            "image_url": "",
            "icon": "fas fa-network-wired",
            "company_name": company_name
        }
        print(f"Creating magic dash: {payload}")
        logger.info(f"Creating magic dash: {payload}")
        headers = {"x-api-key": api_key}
        response = requests.post(url, json=payload, headers=headers)
        response.raise_for_status()
        return response.json(), None
    except requests.exceptions.RequestException as e:
        return None, f"Error creating magic dash: {e}"


import requests

def get_companies_all(api_baseurl, api_key):
    page = 1
    headers = {'x-api-key': api_key}
    all_companies = []
    page_size = 100

    while True:
        url = f'{api_baseurl}/companies?page={page}&page_size={page_size}'
        try:
            response = requests.get(url, headers=headers)
            response.raise_for_status()
            data = response.json()
            
            companies = data.get('companies', [])
            if not companies:
                break
            
            all_companies.extend(companies)

            if len(companies) < page_size:
                break
            
            page += 1
        
        except requests.exceptions.RequestException as e:
            return {"companies": []}, f"Error fetching companies: {e}"
    
    return all_companies, None



import requests

def get_assets_by_layout_id(api_baseurl, api_key, asset_layout_id):
    page = 1
    headers = {'x-api-key': api_key}
    all_assets = []
    page_size = 100  # Adjust as needed

    while True:
        url = f'{api_baseurl}/assets?asset_layout_id={asset_layout_id}&page={page}&page_size={page_size}'
        try:
            response = requests.get(url, headers=headers)
            response.raise_for_status()  # Raise an HTTPError for bad responses
            data = response.json()
            
            assets = data.get('assets', [])
            if not assets:  # If no assets are returned, break the loop
                break
            
            all_assets.extend(assets)

            # If fewer assets are returned than per_page, it's the last page
            if len(assets) < page_size:
                break
            
            page += 1
        
        except requests.exceptions.RequestException as e:
            return {"assets": []}, f"Error fetching assets: {e}"
    
    return all_assets, None
